@@ -2,8 +2,6 @@
  *
  * XCDDEFAULT.H - Header file for default comment data routines
  *
- * Copyright (c) 2000-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   12-26-2006
  *
  * License:
  *
@@ -24,15 +22,7 @@
 
 #ifndef _XCDDEFAULT_H
 #define _XCDDEFAULT_H
-
-#ifdef NSCORE
-int xcddefault_initialize_comment_data(char *);
-int xcddefault_cleanup_comment_data(char *);
-int xcddefault_save_comment_data(void);
-int xcddefault_add_new_host_comment(int,char *,time_t,char *,char *,int,int,int,time_t,unsigned long *);
-int xcddefault_add_new_service_comment(int,char *,char *,time_t,char *,char *,int,int,int,time_t,unsigned long *);
-int xcddefault_delete_host_comment(unsigned long);
-int xcddefault_delete_service_comment(unsigned long);
-#endif
-
+int xcddefault_initialize_comment_data(void);
+int xcddefault_add_new_host_comment(int, char *, time_t, char *, char *, int, int, int, time_t, unsigned long *);
+int xcddefault_add_new_service_comment(int, char *, char *, time_t, char *, char *, int, int, int, time_t, unsigned long *);
 #endif
