@@ -2,8 +2,6 @@
  *
  * XPDDEFAULT.H - Include file for default performance data routines
  *
- * Copyright (c) 2001-2006 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   02-28-2006
  *
  * License:
  *
@@ -28,24 +26,17 @@
 #include "../include/objects.h"
 
 
-#define DEFAULT_HOST_PERFDATA_FILE_TEMPLATE "[HOSTPERFDATA]\t$TIMET$\t$HOSTNAME$\t$HOSTEXECUTIONTIME$\t$HOSTOUTPUT$\t$HOSTPERFDATA$"
-#define DEFAULT_SERVICE_PERFDATA_FILE_TEMPLATE "[SERVICEPERFDATA]\t$TIMET$\t$HOSTNAME$\t$SERVICEDESC$\t$SERVICEEXECUTIONTIME$\t$SERVICELATENCY$\t$SERVICEOUTPUT$\t$SERVICEPERFDATA$"
-
-
-
-int xpddefault_initialize_performance_data(char *);
-int xpddefault_cleanup_performance_data(char *);
-int xpddefault_grab_config_info(char *);
-int xpddefault_grab_config_directives(char *);
+int xpddefault_initialize_performance_data(const char *);
+int xpddefault_cleanup_performance_data(void);
 
 int xpddefault_update_service_performance_data(service *);
 int xpddefault_update_host_performance_data(host *);
 
-int xpddefault_run_service_performance_data_command(service *);
-int xpddefault_run_host_performance_data_command(host *);
+int xpddefault_run_service_performance_data_command(nagios_macros *mac, service *);
+int xpddefault_run_host_performance_data_command(nagios_macros *mac, host *);
 
-int xpddefault_update_service_performance_data_file(service *);
-int xpddefault_update_host_performance_data_file(host *);
+int xpddefault_update_service_performance_data_file(nagios_macros *mac, service *);
+int xpddefault_update_host_performance_data_file(nagios_macros *mac, host *);
 
 int xpddefault_preprocess_file_templates(char *);
 
